# Watchers

Each of these is a Watcher that the user can request.

 - [urls](urls) to watch for changes in websites (default)
 - [psutils](psutils) to get basic system statistics

More watchers will be added as the library is developed.
